@@ -2,5 +2,6 @@ from django.db.models import *
 
 from ohashi.db.models.fields import *
 from ohashi.db.models.fields.birthdays import BirthdayField
-from ohashi.db.models.fields.uuid import UUIDField
+from ohashi.db.models.fields.uuids import UUIDField
+from ohashi.db.models.fields.pickle import PickledObjectField
 from ohashi.db.models.managers.birthdays import BirthdayManager
